function [t,y] = EulerSolve(f,y0,T,h)
%EULERSOLVE explicit euler ODE solver
%   [T,Y] = EULERSOLVE(F,Y0,[T0 T1],H) solves the ODE y'=f(t,y) over the
%   interval [T0 T1] with y(T0) = Y0 using the explicit Euler method with
%   step size (at most) H.  The input argument F should be a function
%   handle taking the arguments (t,y) and returning a column vector
%   corresponding to f(t,y).

% C.J. Gittelson / SAM ETHZ / 2008

% Initialize variables
N = ceil((T(2)-T(1))/h); % number of steps
h = (T(2)-T(1))/N; % adjust step size to fit interval length
d = size(y0,1); % dimension of solution
t = linspace(T(1),T(2),N+1); % time grid
y = nan(d,N+1); % solution
y(:,1) = y0; % set initial value

% Compute solution
for j=1:N
  y(:,j+1) = EulerStep(f,y(:,j),t(j),h);
end

return