function [t,y] = ImpMidPointSolveWithEuler(f,y0,T,h,tol)
%IMPMIDPOINTSOLVE imlpicit mid-point ODE solver
%   [T,Y] = IMPMIDPOINTSOLVEWITHEULER(F,Y0,[T0 T1],H,TOL) solves the ODE
%   y'=f(t,y) over the interval [T0 T1] with y(T0) = Y0 using the implicit
%   mid-point method with step size (at most) H by performing a 'half step' of
%   implicit Euler, then a 'half step' of explicit Euler. The input argument
%   F should be a function handle taking the arguments (t,y) and return a
%   column vector corresponding to f(t,y).

% D.D. Wright, C.J. Gittelson / SAM ETHZ / 2008

% Initialize variables
N = ceil((T(2)-T(1))/h); % number of steps
h = (T(2)-T(1))/N; % adjust step size to fit interval length
d = size(y0,1); % dimension of solution
t = linspace(T(1),T(2),N+1); % time grid
y = nan(d,N+1); % solution
y(:,1) = y0; % set initial value
fval = f(T(1),y0); % initial right hand side

% Compute solution
for j=1:N
  [yhalf,fval] = ;      % Call Implicit Euler method for the first half
  y(:,j+1) = ;       % Call Explicit Euler method for the second half
end

return