function [t,y,err] = RK4Solve(f,y0,T,h)
%RK4Solve Runge-Kutta 4 ODE solver (the classic RK4)
%   [T,Y] = RK4SOLVE(F,Y0,[T0 T1],H) solves the ODE y'=f(t,y) over the interval
%   [T0 T1] with y(T0) = Y0 using the classical Runge-Kutta order 4 method (see
%   the Butcher Table below) with step size (at most) H.  The input argument F
%   should be a function handle taking the arguments (t,y) and returning a
%   column vector corresponding to f(t,y).
%
%   Butcher Table:
%     0  | 
%    1/2 | 1/2
%    1/2 |  0  1/2
%     1  |  0   0   1
%    ____|________________
%        | 1/6 1/3 1/3 1/6

% D.D. Wright, C.J. Gittelson / SAM ETHZ / 2008

% Initialize variables
N = ceil((T(2)-T(1))/h); % number of steps
h = (T(2)-T(1))/N; % adjust step size to fit interval length
d = size(y0,1); % dimension of solution
t = linspace(T(1),T(2),N+1); % time grid
y = nan(d,N+1); % solution
y(:,1) = y0; % set initial value

% Compute solution
for j=1:N
  y(:,j+1) = RK4Step(f,y(:,j),t(j),h);
end

return

function y1 = RK4Step(f,y0,t0,h)

  k = nan(size(y0,1),4);
  
  % Finish Runge-Kutta Method Here
  
  k(:,1) =  ;
  k(:,2) =  ;
  k(:,3) =  ;
  k(:,4) =  ;

  y1 = y0 + ;

return
