% Explicit & implicit Euler, Mid-Point Rule and RK4 for the mathematical
% pendulum.

% C.J. Gittelson, modified by D.D. Wright / SAM ETHZ / 2008

% Define right hand side of IVP here
f = @(t,y) ;

% Define problem and discretization parameters
y0 = ;      % Define the Initial Value here
T = [0 8];
h = 0.25;
tol = 1e-6;

% Call Explicit Euler method, Implicit Euler method and Implicit Midpoint
% method here
[t,yExp] = EulerSolve(f,y0,T,h);
[t,yImp] = ImpEulerSolve(f,y0,T,h,tol);
[t,yImpMidPoint] = ImpMidPointSolve(f,y0,T,h,tol);
% or implicit mid-point using explicit and implicit half-steps:
% [t,yImpMidPoint] = ImpMidPointSolveWithEuler(f,y0,T,h,tol);

% Plot solution in phase space
figure;
plot(mod(yExp(1,:)+pi,2*pi)-pi,yExp(2,:),'bo-');
hold on;
plot(mod(yImp(1,:)+pi,2*pi)-pi,yImp(2,:),'r^-');
plot(mod(yImpMidPoint(1,:)+pi,2*pi)-pi,yImpMidPoint(2,:),...
     'gx-','MarkerSize',16);
hold off;
title(['\bf Numerical Methods for the Mathematical Pendulum, T=' num2str(T(2)) ...
      ' h=' num2str(h)]);
legend('explicit','implicit','implicit midpoint');
xlabel('\alpha');
ylabel('p');
set(gca,'XLim',[-pi pi]);


% Call Implicit Midpoint method and RK4 here
figure;
T = [0 500];
h = 1;
[t,yImpMidPoint] = ImpMidPointSolve(f,y0,T,h,tol);
% or implicit mid-point using explicit and implicit half-steps:
% [t,yImpMidPoint] = ImpMidPointSolveWithEuler(f,y0,T,h,tol);
[t,yRK4] = RK4Solve(f,y0,T,h);
plot(mod(yImpMidPoint(1,:)+pi,2*pi)-pi,yImpMidPoint(2,:),...
     'gx-','MarkerSize',16);
hold on;
plot(mod(yRK4(1,:)+pi,2*pi)-pi,yRK4(2,:),'ms-');
title(['\bf Numerical Methods for the Mathematical Pendulum, T=' num2str(T(2)) ...
      ' h=' num2str(h)]);
legend('implicit midpoint','RK4');
xlabel('\alpha');
ylabel('p');
axis square;
